==> drd-8.x-3.3.tar.gz: drd/src/Entity/DomainInterface.php <==
<?php

/**
 * @file
 * Contains \Drupal\drd\Entity\DomainInterface.
 */

namespace Drupal\drd\Entity;

use Drupal\Core\Url;

/**
 * Provides an interface for defining Domain entities.
 *
 * @ingroup drd
 */
interface DomainInterface extends BaseInterface {

  /**
   * Gets the Domain core.
   *
   * @return Core
   *   Core of the Domain.
   */
  public function getCore();

  /**
   * Sets the Domain core.
   *
   * @param Core $core
   *   The Domain core.
   *
   * @return \Drupal\drd\Entity\DomainInterface
   *   The called Domain entity.
   */
  public function setCore($core);

  /**
   * @param string|null $type
   * @param bool $for_remote
   * @return array
   */
  public function getAuthSetting($type = NULL, $for_remote = FALSE);

  /**
   * @param string|null $type
   * @return array
   */
  public function getCryptSetting($type = NULL);

  /**
   * @param Core $core
   * @param string $uri
   * @param array $extra_values
   * @return \Drupal\drd\Entity\DomainInterface
   * @throws \Exception
   */
  public static function instanceFromUrl($core, $uri, $extra_values);

  /**
   * @param string $query
   * @return \Drupal\Core\Url
   */
  public function buildUrl($query = '');

  /**
   * @return mixed
   *  - FALSE if we can't connect to the given domain
   *  - NULL if we were able to connect but without the expected DRD result
   *  - the unserialized response from the remote DRD
   */
  public function getSupportedCryptMethods();

  /**
   * @param string $token
   * @return bool
   */
  public function pushOTT($token);

  /**
   * @return bool
   */
  public function isDefaultPort();

  /**
   * @var string|bool $redirect
   * @return string
   */
  public function getRemoteSetupToken($redirect);

  /**
   * @var string $label
   * @return string
   */
  public function getRemoteLoginLink($label);

  /**
   * @var bool $initial
   * @return Url
   */
  public function getRemoteSetupRedirect($initial = FALSE);

  /**
   * @var string $label
   * @var bool $initial
   * @return string
   */
  public function getRemoteSetupLink($label, $initial = FALSE);

  /**
   * @return bool
   */
  public function ping();

  /**
   * @return array
   */
  public function remoteInfo();

  /**
   * @param Core $core
   * @throws \Exception
   */
  public function initCore($core);

  /**
   * @param string $name
   * @param string $crypt
   * @param array $crypt_setting
   * @return
   */
  public function initValues($name, $crypt = NULL, $crypt_setting = []);

  /**
   * Callback to retrieve all domains from the remote Drupal installation.
   *
   * @param \Drupal\drd\Entity\Core $core
   */
  public function retrieveAllDomains($core);

  /**
   * @param array $aliase
   * @return \Drupal\drd\Entity\DomainInterface
   *   The called Domain entity.
   */
  public function setAliase($aliase);

  /**
   * @param string $url
   * @return \Drupal\drd\Entity\DomainInterface
   *   The called Domain entity.
   */
  public function updateScheme($url);

  /**
   * @param array $releases
   * @return \Drupal\drd\Entity\DomainInterface
   *   The called Domain entity.
   */
  public function setReleases($releases);

  /**
   * @param bool $refresh
   * @return bool
   */
  public function getMaintenanceMode($refresh = TRUE);

  /**
   * @param bool $refresh
   * @return string|bool
   */
  public function getRemoteBlock($module, $delta, $refresh = TRUE);

  /**
   * @param bool $refresh
   * @return string|bool
   */
  public function getRequirements($refresh = TRUE);

  /**
   * @param array $messages
   * @return \Drupal\drd\Entity\DomainInterface
   *   The called Domain entity.
   */
  public function cacheRemoteMessages($messages);

  /**
   * @param bool $mode
   * @return \Drupal\drd\Entity\DomainInterface
   *   The called Domain entity.
   */
  public function cacheMaintenanceMode($mode);

  /**
   * @param $module
   * @param $delta
   * @param $content
   * @return \Drupal\drd\Entity\DomainInterface
   *   The called Domain entity.
   */
  public function cacheBlock($module, $delta, $content);

  /**
   * @param string $log
   * @return \Drupal\drd\Entity\DomainInterface
   *   The called Domain entity.
   */
  public function cacheErrorLog($log);

  /**
   * @param array $requirements
   * @return \Drupal\drd\Entity\DomainInterface
   *   The called Domain entity.
   */
  public function cacheRequirements($requirements);

  /**
   * @param array $variables
   * @return \Drupal\drd\Entity\DomainInterface
   *   The called Domain entity.
   */
  public function cacheVariables($variables);

  /**
   * @param array $globals
   * @return \Drupal\drd\Entity\DomainInterface
   *   The called Domain entity.
   */
  public function cacheGlobals($globals);

  /**
   * Set Crypt method and Cipher to the strongest available values and generate
   * a new key for that new crypto setting.
   *
   * @return \Drupal\drd\Entity\DomainInterface
   *   The called Domain entity.
   */
  public function resetCryptSettings();

  /**
   * Reset the domain so that new authorization with remote site gets available
   * in the UI again.
   *
   * @return \Drupal\drd\Entity\DomainInterface
   *   The called Domain entity.
   */
  public function reset();

}

==> drd-8.x-3.4.tar.gz: drd/src/Entity/DomainInterface.php <==
<?php

namespace Drupal\drd\Entity;

use Drupal\Core\Url;

/**
 * Provides an interface for defining Domain entities.
 *
 * @ingroup drd
 */
interface DomainInterface extends BaseInterface {

  /**
   * Gets the Domain core.
   *
   * @return CoreInterface
   *   Core of the Domain.
   */
  public function getCore();

  /**
   * Sets the Domain core.
   *
   * @param CoreInterface $core
   *   The Domain core.
   *
   * @return DomainInterface
   *   The called Domain entity.
   */
  public function setCore($core);

  /**
   * @param string|null $type
   * @param bool $for_remote
   * @return array
   */
  public function getAuthSetting($type = NULL, $for_remote = FALSE);

  /**
   * @param string|null $type
   * @return array
   */
  public function getCryptSetting($type = NULL);

  /**
   * @param CoreInterface $core
   * @param string $uri
   * @param array $extra_values
   * @return DomainInterface
   * @throws \Exception
   */
  public static function instanceFromUrl($core, $uri, $extra_values);

  /**
   * @param string $query
   * @return Url
   */
  public function buildUrl($query = '');

  /**
   * @return mixed
   *  - FALSE if we can't connect to the given domain
   *  - NULL if we were able to connect but without the expected DRD result
   *  - the unserialized response from the remote DRD
   */
  public function getSupportedCryptMethods();

  /**
   * @param string $token
   * @return bool
   */
  public function pushOTT($token);

  /**
   * @return bool
   */
  public function isDefaultPort();

  /**
   * @var string|bool $redirect
   * @return string
   */
  public function getRemoteSetupToken($redirect);

  /**
   * @var string $label
   * @return string
   */
  public function getRemoteLoginLink($label);

  /**
   * @var bool $initial
   * @return Url
   */
  public function getRemoteSetupRedirect($initial = FALSE);

  /**
   * @var string $label
   * @var bool $initial
   * @return string
   */
  public function getRemoteSetupLink($label, $initial = FALSE);

  /**
   * @return string
   */
  public function getLocalUrl();

  /**
   * @return string
   */
  public function getSessionUrl();

  /**
   * @return string[]
   */
  public function database();

  /**
   * @param string $source
   * @param string $destination
   *
   * @return bool
   */
  public function download($source, $destination);

  /**
   * @return bool
   */
  public function ping();

  /**
   * @return array
   */
  public function remoteInfo();

  /**
   * @param CoreInterface $core
   * @throws \Exception
   */
  public function initCore($core);

  /**
   * @param string $name
   * @param string $crypt
   * @param array $crypt_setting
   */
  public function initValues($name, $crypt = NULL, $crypt_setting = []);

  /**
   * Callback to retrieve all domains from the remote Drupal installation.
   *
   * @param CoreInterface $core
   */
  public function retrieveAllDomains($core);

  /**
   * @param array $aliase
   * @return DomainInterface
   *   The called Domain entity.
   */
  public function setAliase($aliase);

  /**
   * @param string $url
   * @return DomainInterface
   *   The called Domain entity.
   */
  public function updateScheme($url);

  /**
   * @param array $releases
   * @return DomainInterface
   *   The called Domain entity.
   */
  public function setReleases($releases);

  /**
   * @param bool $refresh
   * @return bool
   */
  public function getMaintenanceMode($refresh = TRUE);

  /**
   * @param bool $refresh
   * @return string|bool
   */
  public function getRemoteBlock($module, $delta, $refresh = TRUE);

  /**
   * @return array
   */
  public function getRemoteSettings();

  /**
   * @return array
   */
  public function getRemoteGlobals();

  /**
   * @param bool $refresh
   * @return array
   */
  public function getRemoteRequirements();

  /**
   * @param array $messages
   * @return DomainInterface
   *   The called Domain entity.
   */
  public function cacheRemoteMessages($messages);

  /**
   * @param bool $mode
   * @return DomainInterface
   *   The called Domain entity.
   */
  public function cacheMaintenanceMode($mode);

  /**
   * @param $module
   * @param $delta
   * @param $content
   * @return DomainInterface
   *   The called Domain entity.
   */
  public function cacheBlock($module, $delta, $content);

  /**
   * @param string $log
   * @return DomainInterface
   *   The called Domain entity.
   */
  public function cacheErrorLog($log);

  /**
   * @param array $requirements
   * @return DomainInterface
   *   The called Domain entity.
   */
  public function cacheRequirements($requirements);

  /**
   * @param array $variables
   * @return DomainInterface
   *   The called Domain entity.
   */
  public function cacheVariables($variables);

  /**
   * @param array $globals
   * @return DomainInterface
   *   The called Domain entity.
   */
  public function cacheGlobals($globals);

  /**
   * @param array $settings
   * @return DomainInterface
   *   The called Domain entity.
   */
  public function cacheSettings($settings);

  /**
   * Set Crypt method and Cipher to the strongest available values and generate
   * a new key for that new crypto setting.
   *
   * @return DomainInterface
   *   The called Domain entity.
   */
  public function resetCryptSettings();

  /**
   * Reset the domain so that new authorization with remote site gets available
   * in the UI again.
   *
   * @return DomainInterface
   *   The called Domain entity.
   */
  public function reset();

}
